/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.advertisement;

import java.rmi.Remote;
import java.rmi.RemoteException;
import com.openexchange.auth.Credentials;
import com.openexchange.exception.OXException;

/**
 * {@link RemoteAdvertisementService}
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.8.3
 */
public interface RemoteAdvertisementService extends Remote {

    public static final String RMI_NAME = RemoteAdvertisementService.class.getSimpleName();

    /**
     * Removes all configurations and mapping for the given reseller. If the given reseller is null, all configurations and mapping are deleted instead.
     * 
     * @param reseller The name of the reseller
     * @param clean
     * @param includePreview
     * @param auth Credentials for authenticating against server.
     * @throws OXException
     */
    public void removeConfigurations(String reseller, boolean clean, boolean includePreview, Credentials auth) throws OXException, RemoteException;

}
